@@ -18,7 +18,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <glib/gprintf.h>
 
 #include "lookup.h"
@@ -140,11 +141,11 @@ lookup_do (Netinfo * netinfo)
 
 /* Process each line from lookup command */
 void
-lookup_foreach (Netinfo * netinfo, gchar * line, gint len,
+lookup_foreach (Netinfo * netinfo, gchar * line, gssize len,
 		gpointer user_data)
 {
 	gchar *text_utf8;
-	gssize bytes_written;
+	gsize bytes_written;
 	GtkTextBuffer *buffer = NULL;
 	GtkTextIter iter;
 	
